# Downloadhelper
```
    Downloadhelper is an Apache2 Licensed HTTP Download library, 
  written in Python, for human beings
```

```python
  >>> from downloadhelper import download
  >>> download('http://partner.myworld2015.org/media/chinese/HOWTO/MYWorld_HowTo_OnlineSurvey_Chinese.pdf', '我的世界.pdf')
  ID:[1/1] Dir: .                                                 
  File: 我的世界.pdf [ 379.82 KB ]
  24.00KB [  6.32%  ] [Speed:  8.00KB/s Timeleft: 00:00:44] 
  (388940, 388940, 0)
```

## Features
--------------------
* support: Resume broken downloads

## Installation
-------------------------
```bash
  $ pip install Downloadhelper
  or
  $ pip install git+https://gitcafe.com/Potter/downloadhelper.git
```
